==> windmill_api-1.8.1-py3-none-any.whl: windmill_api/api/workspace/validate_username.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.validate_username_json_body import ValidateUsernameJsonBody
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ValidateUsernameJsonBody,
) -> Dict[str, Any]:
    url = "{}/workspaces/validate_username".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ValidateUsernameJsonBody,
) -> Response[Any]:
    """validate username

    Args:
        json_body (ValidateUsernameJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    json_body: ValidateUsernameJsonBody,
) -> Response[Any]:
    """validate username

    Args:
        json_body (ValidateUsernameJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)

==> windmill_api-1.8.4-py3-none-any.whl: windmill_api/api/workspace/validate_username.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.validate_username_json_body import ValidateUsernameJsonBody
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ValidateUsernameJsonBody,
) -> Dict[str, Any]:
    url = "{}/workspaces/validate_username".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ValidateUsernameJsonBody,
) -> Response[Any]:
    """validate username

    Args:
        json_body (ValidateUsernameJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    json_body: ValidateUsernameJsonBody,
) -> Response[Any]:
    """validate username

    Args:
        json_body (ValidateUsernameJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)
